User Guide
==========

Once `django_dicom` is properly `installed <installation.html>`_ and `integrated <quickstart.html>`_
into your `Django <https://www.djangoproject.com/>`_ `project <https://docs.djangoproject.com/en/2.2/ref/applications/>`_,
enter your project's shell by running ``python manage.py shell`` from within your project's
`virtual environment <https://docs.python.org/3/tutorial/venv.html>`_.


.. toctree::
    :maxdepth: 2

    importing_data
    reading_header
    reading_data